@@ -1,8 +1,3 @@
-#[macro_use]
-extern crate log;
-#[macro_use]
-extern crate glib;
-
 use gettextrs::*;
 
 mod application;
@@ -15,15 +10,18 @@ use application::Application;
 use config::{GETTEXT_PACKAGE, LOCALEDIR};
 
 fn main() {
+    pretty_env_logger::init();
     // Prepare i18n
     setlocale(LocaleCategory::LcAll, "");
     bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
     textdomain(GETTEXT_PACKAGE);
 
-    glib::set_application_name(&format!("Tour{}", config::NAME_SUFFIX));
+    glib::set_application_name("Tour");
     glib::set_prgname(Some("Tour"));
 
     gtk::init().expect("Unable to start GTK3");
+    #[cfg(feature = "video")]
+    gst::init().expect("Unable to start gst");
 
     static_resources::init().expect("Failed to initialize the resource file.");
 
